@@ -30,24 +30,26 @@ class DefaultRouter:
         """
         return random.choice(model.write_db_aliases)
 
-    def allow_migrate(self, db_alias: str, app_label: str, operation: Operation,
-                      model=None, **hints) -> bool:
+    def allow_migrate(self, db_alias: str, app_label: str, operation: Operation, **hints) -> bool:
         """
         Checks if migration can be applied to given database
         :param db_alias: Database alias to check
         :param app_label: App from which migration is got
         :param operation: Operation object to perform
-        :param model: Model migration is applied to
         :param hints: Hints to make correct decision
         :return: boolean
         """
         if hints.get("force_migrate_on_databases", None):
             return db_alias in hints["force_migrate_on_databases"]
 
-        if hints.get('model'):
-            model = '%s.%s.%s' % (app_label, config.MODELS_MODULE, hints['model']) \
-                if isinstance(hints['model'], str) else hints['model']
+        model = hints.get('model') or getattr(operation, 'model_class', None)
+        if model is None:
+            raise ValueError('"model_class" attribute is not defined for operation "%s". '
+                             'Please provide "force_migrate_on_databases" or "model" in hints.'
+                             % operation.__class__.__name__)
 
+        model = '%s.%s.%s' % (app_label, config.MODELS_MODULE, model) \
+            if isinstance(model, str) else model
         model = lazy_class_import(model)
 
         if operation.__class__ not in {CreateTable, DropTable}:
